package com.ruoyi.frequency.voteoption.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.code.PublicCommon;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.frequency.voteoption.entity.VoteOption;
import com.ruoyi.frequency.voteoption.mapper.VoteOptionMapper;
import com.ruoyi.frequency.voteoption.service.VoteOptionService;
import com.ruoyi.vo.UserVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 投票选项Service业务层处理
 *
 * @author liwenlong
 * @date 2023-10-12
 */
@Service
@Transactional(rollbackFor = Exception.class)
public class VoteOptionServiceImpl extends ServiceImpl<VoteOptionMapper, VoteOption>  implements VoteOptionService
{
    @Autowired
    private VoteOptionMapper voteOptionMapper;

    /**
     * 查询投票选项
     *
     * @param id 投票选项主键
     * @return 投票选项
     */
    @Override
    public VoteOption selectVoteOptionById(Long id)
    {
        return voteOptionMapper.selectVoteOptionById(id);
    }

    /**
     * 查询投票选项列表
     *
     * @param voteOption 投票选项
     * @return 投票选项
     */
    @Override
    public List<VoteOption> selectVoteOptionList(VoteOption voteOption)
    {
        return voteOptionMapper.selectVoteOptionList(voteOption);
    }

    /**
     * 新增投票选项
     *
     * @param voteOption 投票选项
     * @return 结果
     */
    @Override
    public int insertVoteOption(VoteOption voteOption)
    {
        return voteOptionMapper.insertVoteOption(voteOption);
    }

    /**
     * 修改投票选项
     *
     * @param voteOption 投票选项
     * @return 结果
     */
    @Override
    public int updateVoteOption(VoteOption voteOption)
    {
        voteOption.setUpdateTime(DateUtils.getNowDate());
        return voteOptionMapper.updateVoteOption(voteOption);
    }

    /**
     * 批量删除投票选项
     *
     * @param ids 需要删除的投票选项主键
     * @return 结果
     */
    @Override
    public int deleteVoteOptionByIds(Long[] ids)
    {
        this.lambdaUpdate().set(VoteOption::getDelFlag,PublicCommon.删除).in(VoteOption::getId,ids).update();
        return ids.length;
    }

    /**
     * 删除投票选项信息
     *
     * @param id 投票选项主键
     * @return 结果
     */
    @Override
    public int deleteVoteOptionById(Long id)
    {
        this.lambdaUpdate().set(VoteOption::getDelFlag,PublicCommon.删除).eq(VoteOption::getId,id).update();
        return 1;
    }

    @Override
    public List<VoteOption> getList(List<Long> voteIds, UserVo userVo) {
        return voteOptionMapper.getList(voteIds,userVo);
    }

}
